Mathematics
~~~~~~~~~~~

* :ref:`spkg_4ti2`
* :ref:`spkg_admcycles`
* :ref:`spkg_benzene`
* :ref:`spkg_bliss`
* :ref:`spkg_buckygen`
* :ref:`spkg_cbc`
* :ref:`spkg_clarabel`
* :ref:`spkg_coxeter3`
* :ref:`spkg_csdp`
* :ref:`spkg_cunningham_tables`
* :ref:`spkg_cvxpy`
* :ref:`spkg_cylp`
* :ref:`spkg_database_cremona_ellcurve`
* :ref:`spkg_database_cubic_hecke`
* :ref:`spkg_database_jones_numfield`
* :ref:`spkg_database_knotinfo`
* :ref:`spkg_database_kohel`
* :ref:`spkg_database_mutation_class`
* :ref:`spkg_database_odlyzko_zeta`
* :ref:`spkg_database_stein_watkins`
* :ref:`spkg_database_stein_watkins_mini`
* :ref:`spkg_database_symbolic_data`
* :ref:`spkg_dsdp`
* :ref:`spkg_e_antic`
* :ref:`spkg_ecos_python`
* :ref:`spkg_fricas`
* :ref:`spkg_frobby`
* :ref:`spkg_gap_jupyter`
* :ref:`spkg_gap_packages`
* :ref:`spkg_glucose`
* :ref:`spkg_gp2c`
* :ref:`spkg_igraph`
* :ref:`spkg_isl`
* :ref:`spkg_jupymake`
* :ref:`spkg_kenzo`
* :ref:`spkg_kerrgeodesic_gw`
* :ref:`spkg_kissat`
* :ref:`spkg_latte_int`
* :ref:`spkg_libnauty`
* :ref:`spkg_libsemigroups`
* :ref:`spkg_lidia`
* :ref:`spkg_lrslib`
* :ref:`spkg_mathics`
* :ref:`spkg_matroid_database`
* :ref:`spkg_mcqd`
* :ref:`spkg_meataxe`
* :ref:`spkg_modular_resolution`
* :ref:`spkg_mpfrcx`
* :ref:`spkg_msolve`
* :ref:`spkg_normaliz`
* :ref:`spkg_ore_algebra`
* :ref:`spkg_osqp_python`
* :ref:`spkg_p_group_cohomology`
* :ref:`spkg_papilo`
* :ref:`spkg_pari_elldata`
* :ref:`spkg_pari_galpol`
* :ref:`spkg_pari_jupyter`
* :ref:`spkg_pari_nftables`
* :ref:`spkg_pari_seadata`
* :ref:`spkg_phitigra`
* :ref:`spkg_plantri`
* :ref:`spkg_polymake`
* :ref:`spkg_polytopes_db_4d`
* :ref:`spkg_pycosat`
* :ref:`spkg_pycryptosat`
* :ref:`spkg_pynormaliz`
* :ref:`spkg_pyscipopt`
* :ref:`spkg_pysingular`
* :ref:`spkg_python_igraph`
* :ref:`spkg_qdldl_python`
* :ref:`spkg_qepcad`
* :ref:`spkg_r`
* :ref:`spkg_rubiks`
* :ref:`spkg_saclib`
* :ref:`spkg_sage_flatsurf`
* :ref:`spkg_sage_numerical_backends_coin`
* :ref:`spkg_sage_numerical_backends_cplex`
* :ref:`spkg_sage_numerical_backends_gurobi`
* :ref:`spkg_scip`
* :ref:`spkg_scip_sdp`
* :ref:`spkg_scs`
* :ref:`spkg_singular_jupyter`
* :ref:`spkg_sirocco`
* :ref:`spkg_slabbe`
* :ref:`spkg_snappy`
* :ref:`spkg_soplex`
* :ref:`spkg_surface_dynamics`
* :ref:`spkg_symengine`
* :ref:`spkg_symengine_py`
* :ref:`spkg_tdlib`
* :ref:`spkg_tides`
* :ref:`spkg_topcom`

Front-end, graphics, document preparation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* :ref:`spkg_dot2tex`
* :ref:`spkg_graphviz`
* :ref:`spkg_jmol`
* :ref:`spkg_jupyter_jsmol`
* :ref:`spkg_pandoc`
* :ref:`spkg_pdf2svg`
* :ref:`spkg_pygraphviz`
* :ref:`spkg_rst2ipynb`
* :ref:`spkg_sage_sws2rst`
* :ref:`spkg_texlive`

Other dependencies
~~~~~~~~~~~~~~~~~~

* :ref:`spkg__bootstrap`
* :ref:`spkg__develop`
* :ref:`spkg__recommended`
* :ref:`spkg__sagemath`
* :ref:`spkg_auditwheel_or_delocate`
* :ref:`spkg_biopython`
* :ref:`spkg_ccache`
* :ref:`spkg_cibuildwheel`
* :ref:`spkg_d3js`
* :ref:`spkg_eigen`
* :ref:`spkg_ffmpeg`
* :ref:`spkg_free_fonts`
* :ref:`spkg_gdb`
* :ref:`spkg_gdbm`
* :ref:`spkg_git`
* :ref:`spkg_github_cli`
* :ref:`spkg_gitpython`
* :ref:`spkg_googletest`
* :ref:`spkg_hypothesis`
* :ref:`spkg_imagemagick`
* :ref:`spkg_libgraphviz`
* :ref:`spkg_libjpeg`
* :ref:`spkg_libogg`
* :ref:`spkg_libxml2`
* :ref:`spkg_llvm`
* :ref:`spkg_macaulay2`
* :ref:`spkg_mpsolve`
* :ref:`spkg_nibabel`
* :ref:`spkg_notedown`
* :ref:`spkg_onetbb`
* :ref:`spkg_pandoc_attributes`
* :ref:`spkg_perl_cpan_polymake_prereq`
* :ref:`spkg_perl_mongodb`
* :ref:`spkg_perl_term_readline_gnu`
* :ref:`spkg_pybtex`
* :ref:`spkg_pyppeteer`
* :ref:`spkg_python_flint`
* :ref:`spkg_pyx`
* :ref:`spkg_sbcl`
* :ref:`spkg_sqlalchemy`
* :ref:`spkg_texlive_luatex`
* :ref:`spkg_texttable`
* :ref:`spkg_valgrind`
* :ref:`spkg_xindy`
